betty.image module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.image module

Manipulate images.

betty.image.resize_cover(original_image: Image, resize_size: tuple[int, None] | tuple[None, int] | tuple[int, int], *, focus: tuple[int, int, int, int] | None = None) → Image

  Resize an image to cover an area.

  Parameters:

    focus – An area within the image of which as much as possible should be part of the resized image.